.BG
.FN mars
.TL
mars: Multivariate Additive Regression Splines
.CS
mars(x, y, w, wp, degree, nk, penalty, thresh, prune, trace, forward.step, prevfit)
.PP
.AG x
a matrix containing the independent variables.
.AG y
a vector containing the response variable, or in the case of multiple responses,
a matrix whose columns are the response values for each variable
.AG w
an optional vector of observation weights.
.AG wp
an optional vector of response weights.
.AG degree
an optional integer specifying maximum interaction degree (default is 1)
.AG nk
an optional integer specifying the maximum number of model terms
.AG penalty
an  optional value specifying the cost per degree of freedom charge (default is 2)
.AG thresh
an  optional value specifying forward stepwise stopping threshold (default is 0.001---see dmarss.r file for details).
.AG prune
an  optional logical value specifying whether the model should be pruned
in a backward stepwise fashion (default is TRUE).
.AG trace 
an  optional logical value specifying whether info should be printed along the
way (default is FALSE).
.AG forward.step
an  optional logical value specifying whether forward stepwise process should
be carried out (default is TRUE).
.AG prevfit 
optional data structure from previous fit. To see the effect of changing
the penalty paramater, one can use prevfit with `forward.step=F'

.RT
structure with the following components:
.RC call
call used to `mars()'
.RC all.terms
term numbers in full model. 1=constant term. remaining terms are in pairs- 2 3, 4 5 etc. all.terms indicates nonsingular set of terms
.RC selected.terms
term numbers in selected model.
.RC penalty
the input penalty value
.RC degree
the input degree  value
.RC thresh
the input threshold value
.RC gcv
gcv of chosen model
.RC factor
 matrix with ijth element =1 if term i has a factor of the form xj > c, =-1
 if term i has a factor of the form xj <= c, and 0 if xj is not in term i
.RC cuts
 matrix with ijth element = cut point c for var j in term i
.RC residuals
 residuals from fit
.RC fitted values
fitted values from fit
.RC lenb
length of full model
.RC coefficients
least squares coefficients for final model
.RC x
the input x matrix.
.PP
This function was coded from scratch, and did not use any of Friedman's
mars code.  It gives quite similar results to  Friedman's program in
our tests, but not exactly the same results. We have not implemented
Friedman's anova decomposition nor are categorical predictors handled
properly yet. Our version does handle multiple response variables,
however. As it is not well-tested, we would like to hear of any bugs.
.PP
 Trevor Hastie and Robert Tibshirani

.SH REFERENCE
J. Friedman "Multivariate Additive Regression Splines". Annals of Statistic 1991
.SA
`predict.mars', `model.matrix.mars'
.EX
a <- mars(x,y)
aa <- predict.mars(a,x)  # get fitted values for predictor matrix x
.KW non-parametric regression
.WR
